#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @import checkmate
#' @import stringr
#' @import utils
#' @import dplyr
#' @import Andromeda
#' @import R6
#' @import sunburstR
#' @import networkD3
#' @importFrom htmlwidgets JS
#' @importFrom stats sd median
#' @importFrom tidyr pivot_wider
#' @importFrom googleVis gvisSankey
#' @importFrom rjson toJSON
#' @importFrom stringi stri_replace_all_fixed
## usethis namespace: end
NULL

# Global Variables
utils::globalVariables(c("x", "y", "rowNumber", "path"))
